==> pymsod-0.1.3.tar.gz: pymsod-0.1.3/README.md <==
# Python OneDrive

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Daserym/Python-OneDrive">
    <img src="images/logo.png" alt="Logo" width="80" height="80">
  </a>

<h3 align="center">Python OneDrive</h3>

  <p align="center">
  Automatically detects the location of OneDrive folders and returns its parent location.
    <br />
    <a href="https://nsquaredlab.github.io/Python-OneDrive/"><strong>Explore the docs »</strong></a>
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
    </li>
    <li><a href="#contact">Contact</a></li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#development-installation">Development Installation</a></li>
        <li><a href="#package-installation">Package Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#license">License</a></li>
  </ol>
</details>


## About The Project

Give a brief introduction into the project.

<!-- CONTACT -->
### Contact

 [Dominik I. Braun](https://www.nsquared.tf.fau.de/person/dominik-braun/) - dome.braun@fau.de

Project Link: [https://github.com/NsquaredLab/Python-OneDrive](https://github.com/NsquaredLab/Python-OneDrive)


<!-- GETTING STARTED -->
## Getting Started

The local set up is made using [Poetry](https://python-poetry.org/). You can install Poetry using the following command.
Note: It is recommeded to install it globally.
```bash
pip install poetry
```

Then, you can install the dependencies in your work area using the following command:
```bash
poetry install
```

### Development installation
If you want to contribute to the project, you can install the development dependencies using the following command:
```bash
poetry install --with dev,docs
```

### Package Installation (Github)
Poetry
```Bash
poetry add git+https://github.com/NsquaredLab/Python-OneDrive.git
```

PIP
```sh
pip install git+https://github.com/NsquaredLab/Python-OneDrive.git
```

### Package Installation (PyPi)
Poetry
```Bash
poetry add Python-OneDrive
```

PIP
```sh
pip install Python-OneDrive
```


<!-- USAGE EXAMPLES -->
## Usage

Examples of how you can use this package can be found in our [examples gallery](https://nsquaredlab.github.io/Python-OneDrive/auto_examples/index.html).


<!-- LICENSE -->
## License

Distributed under the GPL-3.0 license License. See `LICENSE.txt` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

==> pymsod-0.1.4.tar.gz: pymsod-0.1.4/README.md <==
# Python OneDrive

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/Daserym/Python-OneDrive">
    <img src="images/logo.png" alt="Logo" width="80" height="80">
  </a>

<h3 align="center">Python OneDrive</h3>

  <p align="center">
  Automatically detects the location of OneDrive folders and returns its parent location (Windows only!).
    <br />
    <a href="https://nsquaredlab.github.io/Python-OneDrive/"><strong>Explore the docs »</strong></a>
  </p>
</div>



<!-- TABLE OF CONTENTS -->
<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
    </li>
    <li><a href="#contact">Contact</a></li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#development-installation">Development Installation</a></li>
        <li><a href="#package-installation">Package Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#license">License</a></li>
  </ol>
</details>


## About The Project

Give a brief introduction into the project.

<!-- CONTACT -->
### Contact

 [Dominik I. Braun](https://www.nsquared.tf.fau.de/person/dominik-braun/) - dome.braun@fau.de

Project Link: [https://github.com/NsquaredLab/Python-OneDrive](https://github.com/NsquaredLab/Python-OneDrive)


<!-- GETTING STARTED -->
## Getting Started

The local set up is made using [Poetry](https://python-poetry.org/). You can install Poetry using the following command.
Note: It is recommeded to install it globally.
```bash
pip install poetry
```

Then, you can install the dependencies in your work area using the following command:
```bash
poetry install
```

### Development installation
If you want to contribute to the project, you can install the development dependencies using the following command:
```bash
poetry install --with dev,docs
```

### Package Installation (Github)
Poetry
```Bash
poetry add git+https://github.com/NsquaredLab/Python-OneDrive.git
```

PIP
```sh
pip install git+https://github.com/NsquaredLab/Python-OneDrive.git
```

### Package Installation (PyPi)
Poetry
```Bash
poetry add Python-OneDrive
```

PIP
```sh
pip install Python-OneDrive
```


<!-- USAGE EXAMPLES -->
## Usage

Examples of how you can use this package can be found in our [examples gallery](https://nsquaredlab.github.io/Python-OneDrive/auto_examples/index.html).


<!-- LICENSE -->
## License

Distributed under the GPL-3.0 license License. See `LICENSE.txt` for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>
